@@ -1149,7 +1149,7 @@ void data_sheet_expat_callback_find_cell_start (void* callbackdata, const XML_Ch
         }
       }
     }
-    //determing value type
+    //determine value type
     if ((t = get_expat_attr_by_name(atts, X("t"))) != NULL && XML_Char_icmp(t, X("s")) == 0)
       data->cell_string_type = shared_string;
     else
@@ -1410,6 +1410,7 @@ DLL_EXPORT_XLSXIO xlsxioreadersheetlist xlsxioread_sheetlist_open (xlsxioreader
   result->sheetcallbackdata.xmlparser = NULL;
   result->sheetcallbackdata.callback = xlsxioread_list_sheets_resumable_callback;
   result->sheetcallbackdata.callbackdata = result;
+  result->xmlparser = NULL;
   result->nextsheetname = NULL;
   if ((result->zipfile = XML_Char_openzip(handle->zip, mainsheetfile, 0)) != NULL) {
     result->xmlparser = expat_process_zip_file_suspendable(result->zipfile, main_sheet_list_expat_callback_element_start, NULL, NULL, &result->sheetcallbackdata);
@@ -1622,7 +1623,7 @@ DLL_EXPORT_XLSXIO int xlsxioread_sheet_next_cell_datetime (xlsxioreadersheet she
   if (pvalue) {
     double value = XML_Char_tod(result);
     if (value != 0) {
-      value = (value - 25569) * 86400;  //converstion from Excel to Unix timestamp
+      value = (value - 25569) * 86400;  //conversion from Excel to Unix timestamp
     }
     *pvalue = value;
   }
